#ifndef bwm_video_io_defs_h_
#define bwm_video_io_defs_h_

// XML Tags
#define VIDEO_SITE "BWM_VIDEO_SITE"
#define SITE_DIR_TAG "videoSiteDir"
#define VIDEO_PATH_TAG "videoPath"
#define CAMERA_PATH_TAG "cameraPath"
// Correspondence Tags
#define CORRESPONDENCES_TAG "Correspondences"
#define CORRESP_TAG "Correspondence"
#define CORR_ELE "CE"
#define CORRESP_WORLD_PT_TAG "corr_world_point"
// Object Tags
#define OBJECTS_TAG "Objects"
#define OBJECT_TAG "Object"
#endif //bwm_video_io_defs_h_
